@@ -1165,6 +1165,7 @@ fi
     let paths = [
       (* /etc/fstab *)
       "/files/etc/fstab/*/spec";
+      "/files/etc/crypttab/*/device";
     ] in
     (* Bootloader config *)
     let paths = paths @ bootloader#augeas_device_patterns in
@@ -1194,20 +1195,37 @@ fi
           device
       in
 
-      if PCRE.matches rex_device_cciss value then (
+      if PCRE.matches rex_device_cciss value ||
+         PCRE.matches rex_device_nvme value ||
+         PCRE.matches rex_device value then (
         let device = PCRE.sub 1
         and part = try PCRE.sub 2 with Not_found -> "" in
-        "/dev/" ^ replace device ^ part
-      )
-      else if PCRE.matches rex_device_nvme value then (
-        let device = PCRE.sub 1
-        and part = try PCRE.sub 2 with Not_found -> "" in
-        "/dev/" ^ replace device ^ part
-      )
-      else if PCRE.matches rex_device value then (
-        let device = PCRE.sub 1
-        and part = try PCRE.sub 2 with Not_found -> "" in
-        "/dev/" ^ replace device ^ part
+        let adjusted_dev = "/dev/" ^ replace device ^ part in
+
+        (* On sles12sp5, the installer puts a non-stable path into
+           /etc/crypttab, like /dev/sda2. If we replace it with eg. /dev/vda2,
+           and then regenerate dracut initrd, systemd cryptab integration
+           doesn't happen correctly, because it all expects /dev/vda2 to
+           exist at initrd creation time..
+
+           We can avoid this by filling in a stable `UUID=<luks UUID>` value.
+           This depends on /dev/sdXX in the guest having the same /dev/sdXX
+           name in the appliance.
+         *)
+        if String.starts_with "/etc/crypttab" path &&
+           String.starts_with "/dev/sd" value then (
+          try
+            let uuid = g#vfs_uuid value in
+            "UUID=" ^ uuid
+          with ex ->
+            warning (f_"failed to translate encrypted device name %s to a UUID \
+                in /etc/crypttab.  This may prevent the guest from booting \
+                after conversion. You may have to manually change the file and \
+                reconvert. The original error was: %s")
+              value (Printexc.to_string ex);
+            adjusted_dev
+        ) else
+          adjusted_dev
       )
       else (* doesn't look like a known device name *)
         value
@@ -1324,13 +1342,15 @@ fi
                   g inspect.i_root "fix uefi boot" fix_script)
               else
                 cant_fix_uefi ()
-            | "ubuntu", 14 ->
+            | ("ubuntu", 14) | ("debian", 12)->
               (* to make a bootable uefi ubuntu 14 we need to
                * copy shim<arch>.efi to UEFI fallback path
                * and rename it to BOOT<arch>.efi, also we copy
                * grub.efi and grub.cfg to UEFI fallback path without renaming *)
               let arch_suffix = String.lowercase_ascii suffix in
 
+              let distro = inspect.i_distro in
+
               let shim =
                 String.concat "" [grub_path; "/shim"; arch_suffix; ".efi"] in
               let uefi_grub_name =
@@ -1346,14 +1366,14 @@ fi
                  * if not, then just don't clean up and leave the temp loader
                  * at UEFI fallback path for simplicity
                  *)
-                if String.find shim "/boot/efi/EFI/ubuntu/shim" >= 0 then
+                if String.find shim (sprintf "/boot/efi/EFI/%s/shim" distro) >= 0 then
                   let fix_script =
                     sprintf
                       "#!/bin/bash\n\
-                       sudo efibootmgr -c -L ubuntu \
-                         -l \\\\EFI\\\\ubuntu\\\\shim%s.efi\n\
+                       sudo efibootmgr -c -L %s \
+                         -l \\\\EFI\\\\%s\\\\shim%s.efi\n\
                        rm -rf %s"
-                      arch_suffix uefi_fallback_path in
+                      distro distro arch_suffix uefi_fallback_path in
                   Firstboot.add_firstboot_script
                     g inspect.i_root "fix uefi boot" fix_script
                 else
