@@ -20,9 +20,4 @@
 
     This module converts a Windows guest to run on KVM. *)
 
-val convert : Guestfs.guestfs -> Types.source -> Types.inspect ->
-              Firmware.i_firmware -> Types.guestcaps_block_type ->
-              bool -> Types.static_ip list ->
-              Types.guestcaps
-
-val post_convert : Guestfs.guestfs -> Types.inspect -> unit
+module Convert_windows : Convert_types.CONVERT
