@@ -110,7 +110,7 @@ module Disk = struct
               if options.read_only then
                 Nbdkit.add_filter cmd "cow";
               Nbdkit.add_arg cmd "file" disk;
-              Nbdkit.add_arg cmd "cache" "none";
+              Nbdkit.reduce_memory_pressure cmd;
               let _, pid = Nbdkit.run_unix socket cmd in
 
               (* --exit-with-parent should ensure nbdkit is cleaned
