@@ -92,7 +92,7 @@ let run_unix socket { disk; snapshot; format; imgopts } =
    *)
   if imgopts then List.push_back args "--image-opts";
 
-  if have_selinux && qemu_nbd_has_selinux_label_option () then (
+  if have_selinux () && qemu_nbd_has_selinux_label_option () then (
     List.push_back args "--selinux-label";
     List.push_back args "system_u:object_r:svirt_socket_t:s0"
   );
@@ -129,7 +129,7 @@ let run_unix socket { disk; snapshot; format; imgopts } =
 If the messages above are not sufficient to diagnose the problem then add the ‘virt-v2v -v -x’ options and examine the debugging output carefully.")
   );
 
-  if have_selinux then (
+  if have_selinux () then (
     (* Note that Unix domain sockets have both a file label and
      * a socket/process label.  Using --selinux-label above
      * only set the socket label, but we must also set the file
